pub struct TopicListing { /* private fields */ }Expand description
One topic returned by AdminClient::list_topics.
Implementations
Sourceimpl TopicListing
impl TopicListing
Sourcepub fn is_internal(&self) -> bool
pub fn is_internal(&self) -> bool
Returns whether Kafka marks this as an internal topic.
Sourcepub fn partition_count(&self) -> usize
pub fn partition_count(&self) -> usize
Returns the number of partitions included in metadata.
Sourcepub fn error_code(&self) -> i16
pub fn error_code(&self) -> i16
Returns Kafka’s raw topic-level metadata error code.
Sourcepub fn is_success(&self) -> bool
pub fn is_success(&self) -> bool
Returns whether Kafka reported a successful topic metadata result.
Sourcepub fn broker_error_kind(&self) -> Option<BrokerErrorKind>
pub fn broker_error_kind(&self) -> Option<BrokerErrorKind>
Returns kafrust’s classification for a non-zero Kafka error code.