Module consumer

Module consumer 

Direct topic/partition consumer API.

Structs

Consumer
Direct Kafka consumer for manually assigned topic partitions.
ConsumerAssignment
Direct consumer topic partition assignment.
ConsumerConfig
Configuration builder for Consumer.
ConsumerPartitionQueue
A bounded queue containing records fetched for one topic partition.
ConsumerRecord
Record fetched from a Kafka topic partition.
ConsumerRecordHeader
Header attached to a fetched Kafka record.
LeaderEpochOffset
The end offset recorded for a requested Kafka partition leader epoch.
PartitionWatermarks
Earliest and latest available offsets for one Kafka topic partition.

Enums

IsolationLevel
Controls whether a consumer can return records from aborted transactions.
OffsetResetPolicy
Starting position used when a consumer has no usable offset.