pub struct ConsumerAssignment { /* private fields */ }Expand description
Direct consumer topic partition assignment.
Implementations
Sourceimpl ConsumerAssignment
impl ConsumerAssignment
Sourcepub fn next_offset(&self) -> i64
pub fn next_offset(&self) -> i64
Returns the next offset that will be fetched or committed.
Sourcepub fn leader_epoch(&self) -> i32
pub fn leader_epoch(&self) -> i32
Returns the latest partition leader epoch observed by this assignment.
The initial value is -1 until a RecordBatch response provides an
epoch. Legacy MessageSet responses do not update this value.