pub struct ProducerBatchReport { /* private fields */ }Expand description
Report returned by a batch produce operation.
Implementations
Sourceimpl ProducerBatchReport
impl ProducerBatchReport
Sourcepub fn records(&self) -> &[ProducerBatchRecordOutcome]
pub fn records(&self) -> &[ProducerBatchRecordOutcome]
Returns per-record outcomes in the same order as input records.
Sourcepub fn into_records(self) -> Vec<ProducerBatchRecordOutcome>
pub fn into_records(self) -> Vec<ProducerBatchRecordOutcome>
Consumes this report and returns per-record outcomes.
Sourcepub fn has_failures(&self) -> bool
pub fn has_failures(&self) -> bool
Returns whether at least one record returned a broker failure.