pub enum ShareAcknowledgementMode {
Explicit,
Implicit,
}Expand description
Controls when records acquired from a share group are acknowledged.
Variants
Explicit
The application must acknowledge every record before the next poll.
Implicit
Records returned by the previous poll are accepted before the next poll.